#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
DOC
"""

from __future__ import print_function

import os, sys

#import bepipred2 as bp
from .utils import get_surface,NETSURFP_BIN,get_volume,get_neighbours,RF_MODEL,rolling_mean,init_rf

class BPBaseError(Exception): pass
class BPInputError(Exception): pass
class BPFeatureError(BPBaseError): pass
class BPPredictError(BPBaseError): pass
RF_MODEL = init_rf() #Unloads the random forest predictor
class Antigen(object):
    """
    Class object of a single antigen sequence.
    """

    def __init__(self, entry_name, sequence):
        self.entry_name  = entry_name
        self.sequence    = sequence.upper()
        self.description = ""
        self.features    = []
        self.netsurfp    = {}
        self.predicted   = []
        
    def pred_netsurfp(self):
        """Initialises a dict of list containing results from NetsurfP {POSITION: [RSA, SS],..}"""
        try:
            self.netsurfp = get_surface(self.sequence)
        except:
            err = 'NetsurfP ({}) failed to predict: {}\n{}'
            raise BPFeatureError(err.format(NETSURFP_BIN,self.entry_name, self.sequence))

    def get_features(self):
        """Setups the features to predict sequence."""

        agvolume = get_volume(self.sequence)
        dataset  = list()
        for agpos in range(len(self.sequence)):
            window = get_neighbours(agpos, self.sequence, self.netsurfp, 9)
            dataset.append(window+[agvolume])

        self.features = dataset

    def predict(self):
        """"""
        try:
            preds = RF_MODEL.predict(self.features)
        except:
            err = 'RandomForest failed to predict: {}\n{}'
            raise BPPredictError(err.format(self.entry_name, self.sequence))

        self.predicted = rolling_mean(preds)





