'''
Created on Oct 14th, 2019
@author: Yan
The code coverage by tests is 80%. (total)  
'''
from unittest import TestCase
import unittest
import os
import sys


# adding dependencies to the Python path
project_dir = os.path.dirname(os.path.realpath(__file__))
deps = os.path.join(project_dir, "deps")
sys.path.append(os.path.join(deps, 'iedbtools-utilities'))

from src.antibody_epitope_prediction import AntibodyEpitopePrediction

'''
Name                                                          Stmts   Miss  Cover
---------------------------------------------------------------------------------
antibody_epitope_prediction.py                                   68      9    87%
deps/iedbtools-utilities/iedbtools_utilities/__init__.py          0      0   100%
deps/iedbtools-utilities/iedbtools_utilities/sequence_io.py      83     24    71%
method_calculation.py                                           254     36    86%
tests.py                                                        144      0   100%
util.py                                                          67     54    19%
---------------------------------------------------------------------------------
TOTAL                                                           616    123    80%
'''

class BepipredTests(TestCase):
    method = 'Bepipred'
    single_seq_file = './test/single_sequence.txt'
    multiple_seq_file = './test/multiple_sequences.txt'
    swissprot = 'P02185'
    def test_single_sequence(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=None, filename=self.single_seq_file,
            window_size=False)
        expected_partly_result = [
            ('Position', 'Residue', 'Score', 'Assignment'), 
            ('1', 'V', '0.121', '.'), 
            ('2', 'L', '0.476', 'E'), 
            ('3', 'S', '0.168', '.'), 
            ('4', 'E', '0.198', '.'), 
            ('5', 'G', '-0.180', '.'), 
            ('6', 'E', '-0.255', '.'), 
            ('7', 'W', '-0.412', '.'), 
            ('8', 'Q', '-0.631', '.'), 
            ('9', 'L', '-1.022', '.'), 
            ('10', 'V', '-1.482', '.'), 
            ('11', 'L', '-1.784', '.'), 
            ('12', 'H', '-1.496', '.'), 
            ('13', 'V', '-1.619', '.'), 
            ('14', 'W', '-1.079', '.'), 
            ('15', 'A', '-0.829', '.'), 
            ('16', 'K', '-0.179', '.'), 
            ('17', 'V', '-0.102', '.'), 
            ('18', 'E', '0.131', '.'), 
            ('19', 'A', '0.516', 'E'), 
            ('20', 'D', '0.686', 'E'), 
            ('21', 'V', '0.805', 'E'), 
            ('22', 'A', '1.015', 'E'), 
            ('23', 'G', '1.003', 'E'), 
            ('24', 'H', '0.705', 'E'), 
            ('25', 'G', '0.121', '.'), 
            ('26', 'Q', '-0.251', '.'), 
            ('27', 'D', '-0.448', '.'), 
            ('28', 'I', '-0.966', '.'), 
            ('29', 'L', '-1.385', '.'), 
            ('30', 'I', '-1.607', '.'), 
            ('31', 'R', '-1.559', '.'), 
        ]
        for row in expected_partly_result: 
            self.assertIn(row, list(result.values())[0]['prediction_result'])

    def test_mutiple_sequences(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=None, filename=self.multiple_seq_file,
            window_size=False)

        expected_partly_result = [
            ('Position', 'Residue', 'Score', 'Assignment'), 
            ('1', 'G', '0.678', 'E'), ('2', 'W', '1.025', 'E'), 
            ('3', 'E', '1.145', 'E'), ('4', 'I', '1.025', 'E'), 
            ('5', 'P', '0.904', 'E'), ('6', 'E', '0.532', 'E'), 
            ('7', 'P', '0.956', 'E'), ('8', 'Y', '0.863', 'E'), 
            ('9', 'V', '1.075', 'E'), ('10', 'W', '0.581', 'E'), 
            ('11', 'D', '0.210', '.'), ('12', 'E', '-0.254', '.'), 
            ('13', 'S', '-0.570', '.'), ('14', 'F', '-0.683', '.'),
        ]
        for row in expected_partly_result: 
            self.assertIn(row, list(result.values())[1]['prediction_result'])

    def test_swissprot(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=self.swissprot, filename=self.single_seq_file,
            window_size=False)

        expected_partly_result = [('Position', 'Residue', 'Score', 'Assignment'), ('1', 'M', '-0.911', '.'), ('2', 'V', '-0.439', '.'), ('3', 'L', '-0.055', '.'), ('4', 'S', '-0.258', '.'), ('5', 'E', '-0.184', '.'), ('6', 'G', '-0.283', '.'), ('7', 'E', '-0.307', '.'), ('8', 'W', '-0.412', '.'), ('9', 'Q', '-0.631', '.'), ('10', 'L', '-1.022', '.'), ('11', 'V', '-1.482', '.'), ('12', 'L', '-1.784', '.'), ('13', 'H', '-1.496', '.'), ('14', 'V', '-1.619', '.'), ('15', 'W', '-1.079', '.'),]
        for row in expected_partly_result: 
            self.assertTrue(row in list(result.values())[0]['prediction_result'])



class ChouFasmanTests(TestCase):
    method = 'Chou-Fasman'
    single_seq_file = './test/single_sequence.txt'
    multiple_seq_file = './test/multiple_sequences.txt'
    swissprot = 'P02185'
    def test_single_sequence(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=None, filename=self.single_seq_file,
            window_size=False)

        expected_partly_result = [('Position', 'Residue', 'Start', 'End', 'Peptide', 'Score'), ('4', 'E', '1', '7', 'VLSEGEW', '0.931'), ('5', 'G', '2', '8', 'LSEGEWQ', '1.0'), ('6', 'E', '3', '9', 'SEGEWQL', '1.0'), ('7', 'W', '4', '10', 'EGEWQLV', '0.867'), ('8', 'Q', '5', '11', 'GEWQLVL', '0.846'), ('9', 'L', '6', '12', 'EWQLVLH', '0.759'), ('10', 'V', '7', '13', 'WQLVLHV', '0.724'), ('11', 'L', '8', '14', 'QLVLHVW', '0.724'), ('12', 'H', '9', '15', 'LVLHVWA', '0.679'), ('13', 'V', '10', '16', 'VLHVWAK', '0.739'), ('14', 'W', '11', '17', 'LHVWAKV', '0.739'), ]
        
        for row in expected_partly_result: 
            self.assertTrue(row in list(result.values())[0]['prediction_result'])

    def test_mutiple_sequences(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=None, filename=self.multiple_seq_file,
            window_size=False)

        expected_partly_result = [('Position', 'Residue', 'Start', 'End', 'Peptide', 'Score'), ('4', 'I', '1', '7', 'GWEIPEP', '1.073'), ('5', 'P', '2', '8', 'WEIPEPY', '1.013'), ('6', 'E', '3', '9', 'EIPEPYV', '0.947'), ('7', 'P', '4', '10', 'IPEPYVW', '0.979'), ('8', 'Y', '5', '11', 'PEPYVWD', '1.12'), ('9', 'V', '6', '12', 'EPYVWDE', '1.009'), ('10', 'W', '7', '13', 'PYVWDES', '1.107'), ('11', 'D', '8', '14', 'YVWDESF', '0.976'), ('12', 'E', '9', '15', 'VWDESFR', '0.949'), ('13', 'S', '10', '16', 'WDESFRV', '0.949'), ('14', 'F', '11', '17', 'DESFRVF', '0.897'), ('15', 'R', '12', '18', 'ESFRVFY', '0.851'),]
        for row in expected_partly_result: 
            self.assertTrue(row in list(result.values())[1]['prediction_result'])

    def test_swissprot(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=self.swissprot, filename=self.single_seq_file,
            window_size=False)

        expected_partly_result = [('Position', 'Residue', 'Start', 'End', 'Peptide', 'Score'), ('4', 'S', '1', '7', 'MVLSEGE', '0.88'), ('5', 'E', '2', '8', 'VLSEGEW', '0.931'), ('6', 'G', '3', '9', 'LSEGEWQ', '1.0'), ('7', 'E', '4', '10', 'SEGEWQL', '1.0'), ('8', 'W', '5', '11', 'EGEWQLV', '0.867'), ('9', 'Q', '6', '12', 'GEWQLVL', '0.846'), ('10', 'L', '7', '13', 'EWQLVLH', '0.759'), ('11', 'V', '8', '14', 'WQLVLHV', '0.724'), ('12', 'L', '9', '15', 'QLVLHVW', '0.724'), ('13', 'H', '10', '16', 'LVLHVWA', '0.679'), ('14', 'V', '11', '17', 'VLHVWAK', '0.739'), ('15', 'W', '12', '18', 'LHVWAKV', '0.739'), ('16', 'A', '13', '19', 'HVWAKVE', '0.76'),]
        for row in expected_partly_result: 
            self.assertTrue(row in list(result.values())[0]['prediction_result'])


class EminiTests(TestCase):
    method = 'Emini'
    single_seq_file = './test/single_sequence.txt'
    multiple_seq_file = './test/multiple_sequences.txt'
    swissprot = 'P02185'
    def test_single_sequence(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=None, filename=self.single_seq_file,
            window_size=False)

        expected_partly_result = [('Position', 'Residue', 'Start', 'End', 'Peptide', 'Score'), ('3', 'S', '1', '6', 'VLSEGE', '0.542'), ('4', 'E', '2', '7', 'LSEGEW', '0.767'), ('5', 'G', '3', '8', 'SEGEWQ', '1.611'), ('6', 'E', '4', '9', 'EGEWQL', '0.992'), ('7', 'W', '5', '10', 'GEWQLV', '0.425'), ('8', 'Q', '6', '11', 'EWQLVL', '0.354'), ('9', 'L', '7', '12', 'WQLVLH', '0.278'), ('10', 'V', '8', '13', 'QLVLHV', '0.196'), ('11', 'L', '9', '14', 'LVLHVW', '0.119'), ('12', 'H', '10', '15', 'VLHVWA', '0.146'), ('13', 'V', '11', '16', 'LHVWAK', '0.394'), ('14', 'W', '12', '17', 'HVWAKV', '0.354'), ('15', 'A', '13', '18', 'VWAKVE', '0.451'), ]
        
        for row in expected_partly_result: 
            self.assertTrue(row in list(result.values())[0]['prediction_result'])

    def test_mutiple_sequences(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=None, filename=self.multiple_seq_file,
            window_size=False)

        expected_partly_result = [('Position', 'Residue', 'Start', 'End', 'Peptide', 'Score'), ('3', 'E', '1', '6', 'GWEIPE', '0.675'), ('4', 'I', '2', '7', 'WEIPEP', '1.055'), ('5', 'P', '3', '8', 'EIPEPY', '1.572'), ('6', 'E', '4', '9', 'IPEPYV', '0.674'), ('7', 'P', '5', '10', 'PEPYVW', '1.011'), ('8', 'Y', '6', '11', 'EPYVWD', '1.092'), ('9', 'V', '7', '12', 'PYVWDE', '1.092'), ('10', 'W', '8', '13', 'YVWDES', '0.946'), ('11', 'D', '9', '14', 'VWDESF', '0.523'), ('12', 'E', '10', '15', 'WDESFR', '1.38'), ('13', 'S', '11', '16', 'DESFRV', '0.974'), ('14', 'F', '12', '17', 'ESFRVF', '0.505'), ('15', 'R', '13', '18', 'SFRVFY', '0.457'),]
        for row in expected_partly_result: 
            self.assertTrue(row in list(result.values())[1]['prediction_result'])

    def test_swissprot(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=self.swissprot, filename=self.single_seq_file,
            window_size=False)

        expected_partly_result = [('Position', 'Residue', 'Start', 'End', 'Peptide', 'Score'), ('3', 'L', '1', '6', 'MVLSEG', '0.307'), ('4', 'S', '2', '7', 'VLSEGE', '0.537'), ('5', 'E', '3', '8', 'LSEGEW', '0.76'), ('6', 'G', '4', '9', 'SEGEWQ', '1.596'), ('7', 'E', '5', '10', 'EGEWQL', '0.982'), ('8', 'W', '6', '11', 'GEWQLV', '0.421'), ('9', 'Q', '7', '12', 'EWQLVL', '0.351'), ('10', 'L', '8', '13', 'WQLVLH', '0.276'), ('11', 'V', '9', '14', 'QLVLHV', '0.195'), ('12', 'L', '10', '15', 'LVLHVW', '0.118'), ('13', 'H', '11', '16', 'VLHVWA', '0.145'), ('14', 'V', '12', '17', 'LHVWAK', '0.39'),]
        for row in expected_partly_result: 
            self.assertTrue(row in list(result.values())[0]['prediction_result'])


class KarplusSchulzTests(TestCase):
    method = 'Karplus-Schulz'
    single_seq_file = './test/single_sequence.txt'
    multiple_seq_file = './test/multiple_sequences.txt'
    swissprot = 'P02185'
    def test_single_sequence(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=None, filename=self.single_seq_file,
            window_size=False)

        expected_partly_result = [('Position', 'Residue', 'Start', 'End', 'Peptide', 'Score'), ('4', 'E', '1', '7', 'VLSEGEW', '1.053'), ('5', 'G', '2', '8', 'LSEGEWQ', '1.047'), ('6', 'E', '3', '9', 'SEGEWQL', '1.02'), ('7', 'W', '4', '10', 'EGEWQLV', '0.98'), ('8', 'Q', '5', '11', 'GEWQLVL', '0.947'), ('9', 'L', '6', '12', 'EWQLVLH', '0.929'), ('10', 'V', '7', '13', 'WQLVLHV', '0.918'), ('11', 'L', '8', '14', 'QLVLHVW', '0.909'), ('12', 'H', '9', '15', 'LVLHVWA', '0.901'), ('13', 'V', '10', '16', 'VLHVWAK', '0.903'), ('14', 'W', '11', '17', 'LHVWAKV', '0.912'), ('15', 'A', '12', '18', 'HVWAKVE', '0.936'), ]
        
        for row in expected_partly_result: 
            self.assertTrue(row in list(result.values())[0]['prediction_result'])

    def test_mutiple_sequences(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=None, filename=self.multiple_seq_file,
            window_size=False)

        expected_partly_result = [('Position', 'Residue', 'Start', 'End', 'Peptide', 'Score'), ('4', 'I', '1', '7', 'GWEIPEP', '1.02'), ('5', 'P', '2', '8', 'WEIPEPY', '1.032'), ('6', 'E', '3', '9', 'EIPEPYV', '1.037'), ('7', 'P', '4', '10', 'IPEPYVW', '1.02'), ('8', 'Y', '5', '11', 'PEPYVWD', '0.994'), ('9', 'V', '6', '12', 'EPYVWDE', '0.983'), ('10', 'W', '7', '13', 'PYVWDES', '0.991'), ('11', 'D', '8', '14', 'YVWDESF', '1.011'), ('12', 'E', '9', '15', 'VWDESFR', '1.018'), ('13', 'S', '10', '16', 'WDESFRV', '1.005'), ('14', 'F', '11', '17', 'DESFRVF', '0.976'), ('15', 'R', '12', '18', 'ESFRVFY', '0.945'),]
        for row in expected_partly_result: 
            self.assertTrue(row in list(result.values())[1]['prediction_result'])

    def test_swissprot(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=self.swissprot, filename=self.single_seq_file,
            window_size=False)

        expected_partly_result = [('Position', 'Residue', 'Start', 'End', 'Peptide', 'Score'), ('4', 'S', '1', '7', 'MVLSEGE', '1.028'), ('5', 'E', '2', '8', 'VLSEGEW', '1.049'), ('6', 'G', '3', '9', 'LSEGEWQ', '1.047'), ('7', 'E', '4', '10', 'SEGEWQL', '1.02'), ('8', 'W', '5', '11', 'EGEWQLV', '0.98'), ('9', 'Q', '6', '12', 'GEWQLVL', '0.947'), ('10', 'L', '7', '13', 'EWQLVLH', '0.929'), ('11', 'V', '8', '14', 'WQLVLHV', '0.918'), ('12', 'L', '9', '15', 'QLVLHVW', '0.909'), ('13', 'H', '10', '16', 'LVLHVWA', '0.901'), ('14', 'V', '11', '17', 'VLHVWAK', '0.903'), ('15', 'W', '12', '18', 'LHVWAKV', '0.912'), ('16', 'A', '13', '19', 'HVWAKVE', '0.936'), ('17', 'K', '14', '20', 'VWAKVEA', '0.965'), ('18', 'V', '15', '21', 'WAKVEAD', '0.975'), ('19', 'E', '16', '22', 'AKVEADV', '0.978'),]
        for row in expected_partly_result: 
            self.assertTrue(row in list(result.values())[0]['prediction_result'])



class KolaskarTongaonkarTests(TestCase):
    method = 'Kolaskar-Tongaonkar'
    single_seq_file = './test/single_sequence.txt'
    multiple_seq_file = './test/multiple_sequences.txt'
    swissprot = 'P02185'
    def test_single_sequence(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=None, filename=self.single_seq_file,
            window_size=False)

        expected_partly_result = [('Position', 'Residue', 'Start', 'End', 'Peptide', 'Score'), ('4', 'E', '1', '7', 'VLSEGEW', '1.016'), ('5', 'G', '2', '8', 'LSEGEWQ', '0.964'), ('6', 'E', '3', '9', 'SEGEWQL', '0.964'), ('7', 'W', '4', '10', 'EGEWQLV', '1.017'), ('8', 'Q', '5', '11', 'GEWQLVL', '1.074'), ('9', 'L', '6', '12', 'EWQLVLH', '1.107'), ('10', 'V', '7', '13', 'WQLVLHV', '1.183'), ('11', 'L', '8', '14', 'QLVLHVW', '1.183'), ('12', 'H', '9', '15', 'LVLHVWA', '1.19'), ('13', 'V', '10', '16', 'VLHVWAK', '1.144'), ('14', 'W', '11', '17', 'LHVWAKV', '1.144'), ('15', 'A', '12', '18', 'HVWAKVE', '1.087'), ('16', 'K', '13', '19', 'VWAKVEA', '1.081'), ('17', 'V', '14', '20', 'WAKVEAD', '1.007'), ('18', 'E', '15', '21', 'AKVEADV', '1.077'), ('19', 'A', '16', '22', 'KVEADVA', '1.077'),]
        
        for row in expected_partly_result: 
            self.assertTrue(row in list(result.values())[0]['prediction_result'])

    def test_mutiple_sequences(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=None, filename=self.multiple_seq_file,
            window_size=False)

        expected_partly_result = [('Position', 'Residue', 'Start', 'End', 'Peptide', 'Score'), ('4', 'I', '1', '7', 'GWEIPEP', '0.964'), ('5', 'P', '2', '8', 'WEIPEPY', '1.005'), ('6', 'E', '3', '9', 'EIPEPYV', '1.075'), ('7', 'P', '4', '10', 'IPEPYVW', '1.081'), ('8', 'Y', '5', '11', 'PEPYVWD', '1.04'), ('9', 'V', '6', '12', 'EPYVWDE', '1.01'), ('10', 'W', '7', '13', 'PYVWDES', '1.033'), ('11', 'D', '8', '14', 'YVWDESF', '1.037'), ('12', 'E', '9', '15', 'VWDESFR', '0.996'), ('13', 'S', '10', '16', 'WDESFRV', '0.996'), ('14', 'F', '11', '17', 'DESFRVF', '1.024'), ('15', 'R', '12', '18', 'ESFRVFY', '1.066'),]
        for row in expected_partly_result: 
            self.assertTrue(row in list(result.values())[1]['prediction_result'])

    def test_swissprot(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=self.swissprot, filename=self.single_seq_file,
            window_size=False)

        expected_partly_result = [('Position', 'Residue', 'Start', 'End', 'Peptide', 'Score'), ('4', 'S', '1', '7', 'MVLSEGE', '1.007'), ('5', 'E', '2', '8', 'VLSEGEW', '1.016'), ('6', 'G', '3', '9', 'LSEGEWQ', '0.964'), ('7', 'E', '4', '10', 'SEGEWQL', '0.964'), ('8', 'W', '5', '11', 'EGEWQLV', '1.017'), ('9', 'Q', '6', '12', 'GEWQLVL', '1.074'), ('10', 'L', '7', '13', 'EWQLVLH', '1.107'), ('11', 'V', '8', '14', 'WQLVLHV', '1.183'), ('12', 'L', '9', '15', 'QLVLHVW', '1.183'), ('13', 'H', '10', '16', 'LVLHVWA', '1.19'), ('14', 'V', '11', '17', 'VLHVWAK', '1.144'), ('15', 'W', '12', '18', 'LHVWAKV', '1.144'),]
        for row in expected_partly_result: 
            self.assertTrue(row in list(result.values())[0]['prediction_result'])


class ParkerTests(TestCase):
    method = 'Parker'
    single_seq_file = './test/single_sequence.txt'
    multiple_seq_file = './test/multiple_sequences.txt'
    swissprot = 'P02185'
    def test_single_sequence(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=None, filename=self.single_seq_file,
            window_size=False)

        expected_partly_result = [('Position', 'Residue', 'Start', 'End', 'Peptide', 'Score'), ('4', 'E', '1', '7', 'VLSEGEW', '0.7'), ('5', 'G', '2', '8', 'LSEGEWQ', '2.086'), ('6', 'E', '3', '9', 'SEGEWQL', '2.086'), ('7', 'W', '4', '10', 'EGEWQLV', '0.629'), ('8', 'Q', '5', '11', 'GEWQLVL', '-1.8'), ('9', 'L', '6', '12', 'EWQLVLH', '-2.314'), ('10', 'V', '7', '13', 'WQLVLHV', '-3.957'), ('11', 'L', '8', '14', 'QLVLHVW', '-3.957'), ('12', 'H', '9', '15', 'LVLHVWA', '-4.514'), ('13', 'V', '10', '16', 'VLHVWAK', '-2.386'), ('14', 'W', '11', '17', 'LHVWAKV', '-2.386'),]
        
        for row in expected_partly_result: 
            self.assertTrue(row in list(result.values())[0]['prediction_result'])

    def test_mutiple_sequences(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=None, filename=self.multiple_seq_file,
            window_size=False)
        
        expected_partly_result = [('Position', 'Residue', 'Start', 'End', 'Peptide', 'Score'), ('4', 'I', '1', '7', 'GWEIPEP', '1.071'), ('5', 'P', '2', '8', 'WEIPEPY', '-0.014'), ('6', 'E', '3', '9', 'EIPEPYV', '0.886'), ('7', 'P', '4', '10', 'IPEPYVW', '-1.657'), ('8', 'Y', '5', '11', 'PEPYVWD', '0.914'), ('9', 'V', '6', '12', 'EPYVWDE', '1.729'), ('10', 'W', '7', '13', 'PYVWDES', '1.543'), ('11', 'D', '8', '14', 'YVWDESF', '-0.071'), ('12', 'E', '9', '15', 'VWDESFR', '0.8'), ('13', 'S', '10', '16', 'WDESFRV', '0.8'), ('14', 'F', '11', '17', 'DESFRVF', '0.914'), ('15', 'R', '12', '18', 'ESFRVFY', '-0.786'), ('16', 'V', '13', '19', 'SFRVFYE', '-0.786'), ('17', 'F', '14', '20', 'FRVFYEQ', '-0.857'), ('18', 'Y', '15', '21', 'RVFYEQL', '-0.857'), ('19', 'E', '16', '22', 'VFYEQLD', '-0.029'),]
        for row in expected_partly_result: 
            self.assertTrue(row in list(result.values())[1]['prediction_result'])

    def test_swissprot(self):
        aep = AntibodyEpitopePrediction()
        result = aep.predict_antibody_epitope(
            method_name=self.method, swissprot=self.swissprot, filename=self.single_seq_file,
            window_size=False)
        expected_partly_result = [('Position', 'Residue', 'Start', 'End', 'Peptide', 'Score'), ('4', 'S', '1', '7', 'MVLSEGE', '1.529'), ('5', 'E', '2', '8', 'VLSEGEW', '0.7'), ('6', 'G', '3', '9', 'LSEGEWQ', '2.086'), ('7', 'E', '4', '10', 'SEGEWQL', '2.086'), ('8', 'W', '5', '11', 'EGEWQLV', '0.629'), ('9', 'Q', '6', '12', 'GEWQLVL', '-1.8'), ('10', 'L', '7', '13', 'EWQLVLH', '-2.314'), ('11', 'V', '8', '14', 'WQLVLHV', '-3.957'), ('12', 'L', '9', '15', 'QLVLHVW', '-3.957'), ('13', 'H', '10', '16', 'LVLHVWA', '-4.514'), ('14', 'V', '11', '17', 'VLHVWAK', '-2.386'),]
        for row in expected_partly_result: 
            self.assertTrue(row in list(result.values())[0]['prediction_result'])


if __name__ == '__main__':
    unittest.main()
